@@ -35,7 +35,15 @@ class VirtualBMCConfig(object):
     DEFAULTS = {
         'default': {
             'show_passwords': 'false',
-            'config_dir': os.path.join(os.path.expanduser('~'), '.vbmc'),
+            'config_dir': os.path.join(
+                os.path.expanduser('~'), '.vbmc'
+            ),
+            'pid_file': os.path.join(
+                os.path.expanduser('~'), '.vbmc', 'master.pid'
+            ),
+            'server_port': 50891,
+            'server_response_timeout': 5000,  # milliseconds
+            'server_spawn_wait': 3000,  # milliseconds
         },
         'log': {
             'logfile': None,
