@@ -15,9 +15,9 @@
 
 import copy
 import errno
+import multiprocessing
 import os
 import shutil
-import signal
 
 import mock
 from six.moves import builtins
@@ -49,7 +49,8 @@ class VirtualBMCManagerTestCase(base.TestCase):
                            'domain_name': 'Squidward Tentacles',
                            'libvirt_uri': 'foo://bar',
                            'libvirt_sasl_username': 'sasl_admin',
-                           'libvirt_sasl_password': 'sasl_pass'}
+                           'libvirt_sasl_password': 'sasl_pass',
+                           'active': 'False'}
 
     def _get_config(self, section, item):
         return self.domain0.get(item)
@@ -69,9 +70,10 @@ class VirtualBMCManagerTestCase(base.TestCase):
 
         expected_get_calls = [mock.call('VirtualBMC', i)
                               for i in ('username', 'password', 'address',
-                                        'domain_name', 'libvirt_uri',
+                                        'port', 'domain_name', 'libvirt_uri',
                                         'libvirt_sasl_username',
-                                        'libvirt_sasl_password')]
+                                        'libvirt_sasl_password',
+                                        'active')]
         self.assertEqual(expected_get_calls, config.get.call_args_list)
 
     @mock.patch.object(os.path, 'exists')
@@ -82,10 +84,8 @@ class VirtualBMCManagerTestCase(base.TestCase):
         mock_exists.assert_called_once_with(self.domain_path0 + '/config')
 
     @mock.patch.object(builtins, 'open')
-    @mock.patch.object(utils, 'is_pid_running')
     @mock.patch.object(manager.VirtualBMCManager, '_parse_config')
-    def _test__show(self, mock__parse, mock_pid, mock_open, expected=None):
-        mock_pid.return_value = True
+    def _test__show(self, mock__parse, mock_open, expected=None):
         mock__parse.return_value = self.domain0
         f = mock.MagicMock()
         f.read.return_value = self.domain0['port']
@@ -93,7 +93,7 @@ class VirtualBMCManagerTestCase(base.TestCase):
 
         if expected is None:
             expected = self.domain0.copy()
-            expected['status'] = manager.RUNNING
+            expected['status'] = manager.DOWN
 
         ret = self.manager._show(self.domain_name0)
         self.assertEqual(expected, ret)
@@ -109,7 +109,7 @@ class VirtualBMCManagerTestCase(base.TestCase):
             expected = self.domain0.copy()
             expected['password'] = '***'
             expected['libvirt_sasl_password'] = '***'
-            expected['status'] = manager.RUNNING
+            expected['status'] = manager.DOWN
             self._test__show(expected=expected)
 
     @mock.patch.object(builtins, 'open')
@@ -168,8 +168,12 @@ class VirtualBMCManagerTestCase(base.TestCase):
         os_error.errno = errno.EEXIST
         mock_makedirs.side_effect = os_error
 
-        self.assertRaises(exception.DomainAlreadyExists,
-                          self.manager.add, **self.add_params)
+        ret, _ = self.manager.add(**self.add_params)
+
+        expected_ret = 1
+
+        self.assertEqual(ret, expected_ret)
+
         mock_check_conn.assert_called_once_with(
             self.add_params['libvirt_uri'], self.add_params['domain_name'],
             sasl_username=self.add_params['libvirt_sasl_username'],
@@ -180,8 +184,10 @@ class VirtualBMCManagerTestCase(base.TestCase):
     def test_add_oserror(self, mock_check_conn, mock_makedirs):
         mock_makedirs.side_effect = OSError
 
-        self.assertRaises(exception.VirtualBMCError,
-                          self.manager.add, **self.add_params)
+        ret, _ = self.manager.add(**self.add_params)
+        expected_ret = 1
+        self.assertEqual(ret, expected_ret)
+
         mock_check_conn.assert_called_once_with(
             self.add_params['libvirt_uri'], self.add_params['domain_name'],
             sasl_username=self.add_params['libvirt_sasl_username'],
@@ -206,67 +212,55 @@ class VirtualBMCManagerTestCase(base.TestCase):
         mock_exists.assert_called_once_with(self.domain_path0)
 
     @mock.patch.object(builtins, 'open')
-    @mock.patch.object(manager, 'VirtualBMC')
-    @mock.patch.object(utils, 'detach_process')
-    @mock.patch.object(utils, 'check_libvirt_connection_and_domain')
     @mock.patch.object(manager.VirtualBMCManager, '_parse_config')
     @mock.patch.object(os.path, 'exists')
-    def test_start(self, mock_exists, mock__parse, mock_check_conn,
-                   mock_detach, mock_vbmc, mock_open):
+    @mock.patch.object(os.path, 'isdir')
+    @mock.patch.object(os, 'listdir')
+    @mock.patch.object(multiprocessing, 'Process')
+    def test_start(self, mock_process, mock_listdir, mock_isdir, mock_exists,
+                   mock__parse, mock_open):
         conf = {'ipmi': {'session_timeout': 10},
                 'default': {'show_passwords': False}}
         with mock.patch('virtualbmc.manager.CONF', conf):
+            mock_listdir.return_value = [self.domain_name0]
+            mock_isdir.return_value = True
             mock_exists.return_value = True
-            mock__parse.return_value = self.domain0
-            mock_detach.return_value.__enter__.return_value = 99999
+            domain0_conf = self.domain0.copy()
+            domain0_conf.update(active='False')
+            mock__parse.return_value = domain0_conf
             file_handler = mock_open.return_value.__enter__.return_value
             self.manager.start(self.domain_name0)
-
-            mock_exists.assert_called_once_with(self.domain_path0)
-            mock__parse.assert_called_once_with(self.domain_name0)
-            mock_check_conn.assert_called_once_with(
-                self.domain0['libvirt_uri'], self.domain0['domain_name'],
-                sasl_username=self.domain0['libvirt_sasl_username'],
-                sasl_password=self.domain0['libvirt_sasl_password'])
-            mock_detach.assert_called_once_with()
-            mock_vbmc.assert_called_once_with(**self.domain0)
-            mock_vbmc.return_value.listen.assert_called_once_with(timeout=10)
-            file_handler.write.assert_called_once_with('99999')
+            mock__parse.assert_called_with(self.domain_name0)
+            self.assertEqual(file_handler.write.call_count, 9)
 
     @mock.patch.object(builtins, 'open')
-    @mock.patch.object(os, 'kill')
-    @mock.patch.object(os, 'remove')
-    @mock.patch.object(os.path, 'exists')
-    def test_stop(self, mock_exists, mock_remove, mock_kill, mock_open):
-        mock_exists.return_value = True
-        f = mock.MagicMock()
-        f.read.return_value = self.domain0['port']
-        mock_open.return_value.__enter__.return_value = f
-
-        self.manager.stop(self.domain_name0)
-        f.read.assert_called_once_with()
-        mock_exists.assert_called_once_with(self.domain_path0)
-        mock_remove.assert_called_once_with(self.domain_path0 + '/pid')
-        mock_kill.assert_called_once_with(self.domain0['port'],
-                                          signal.SIGKILL)
+    @mock.patch.object(manager.VirtualBMCManager, '_parse_config')
+    @mock.patch.object(os.path, 'isdir')
+    @mock.patch.object(os, 'listdir')
+    def test_stop(self, mock_listdir, mock_isdir, mock__parse, mock_open):
+        conf = {'ipmi': {'session_timeout': 10},
+                'default': {'show_passwords': False}}
+        with mock.patch('virtualbmc.manager.CONF', conf):
+            mock_listdir.return_value = [self.domain_name0]
+            mock_isdir.return_value = True
+            domain0_conf = self.domain0.copy()
+            domain0_conf.update(active='True')
+            mock__parse.return_value = domain0_conf
+            file_handler = mock_open.return_value.__enter__.return_value
+            self.manager.stop(self.domain_name0)
+            mock_isdir.assert_called_once_with(self.domain_path0)
+            mock__parse.assert_called_with(self.domain_name0)
+            self.assertEqual(file_handler.write.call_count, 9)
 
     @mock.patch.object(os.path, 'exists')
     def test_stop_domain_not_found(self, mock_exists):
         mock_exists.return_value = False
-        self.assertRaises(exception.DomainNotFound,
-                          self.manager.stop, self.domain_name0)
-        mock_exists.assert_called_once_with(self.domain_path0)
-
-    @mock.patch.object(builtins, 'open')
-    @mock.patch.object(os.path, 'exists')
-    def test_stop_pid_file_not_found(self, mock_exists, mock_open):
-        mock_exists.return_value = True
-        f = mock.MagicMock()
-        f.read.return_value = self.domain0['port']
-        mock_open.return_value.__enter__.side_effect = IOError('boom')
-
-        self.assertRaises(exception.VirtualBMCError,
-                          self.manager.stop, self.domain_name0)
+        ret = self.manager.stop(self.domain_name0)
+        expected_ret = 1, 'No domain with matching name SpongeBob was found'
+        self.assertEqual(ret, expected_ret)
+        mock_exists.assert_called_once_with(
+            os.path.join(self.domain_path0, 'config')
+        )
 
     @mock.patch.object(os.path, 'isdir')
     @mock.patch.object(os, 'listdir')
@@ -274,16 +268,17 @@ class VirtualBMCManagerTestCase(base.TestCase):
     def test_list(self, mock__show, mock_listdir, mock_isdir):
         mock_isdir.return_value = True
         mock_listdir.return_value = (self.domain_name0, self.domain_name1)
-        expected_ret = [self.domain0, self.domain1]
-        mock__show.side_effect = expected_ret
-        ret = self.manager.list()
 
-        self.assertEqual(expected_ret, ret)
+        ret, _ = self.manager.list()
+        expected_ret = 0
+        self.assertEqual(ret, expected_ret)
         mock_listdir.assert_called_once_with(_CONFIG_PATH)
-
         expected_calls = [mock.call(self.domain_path0),
                           mock.call(self.domain_path1)]
         self.assertEqual(expected_calls, mock_isdir.call_args_list)
+        expected_calls = [mock.call(self.domain_name0),
+                          mock.call(self.domain_name1)]
+        self.assertEqual(expected_calls, mock__show.call_args_list)
 
     @mock.patch.object(manager.VirtualBMCManager, '_show')
     def test_show(self, mock__show):
